package com.steerinfo.dil.service.impl;

import com.alibaba.druid.sql.visitor.functions.If;
import com.steerinfo.dil.feign.AmsFeign;
import com.steerinfo.dil.feign.BmsTruckFeign;
import com.steerinfo.dil.feign.OmsFeign;
import com.steerinfo.dil.mapper.TmstruckTimeTaskResultMapper;
import com.steerinfo.dil.mapper.UtilsMapper;
import com.steerinfo.dil.model.TmstruckTimeTaskResult;
import com.steerinfo.dil.service.ITmstruckTimeTaskResultService;

import com.steerinfo.dil.util.DataChange;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.xml.crypto.Data;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.*;
import java.util.stream.Collectors;

/**
 * TmstruckTimeTskResult服务实现：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-22 07:28
 * 类描述
 * 修订历史：
 * 日期：2021-10-22
 * 作者：generator
 * 参考：
 * 描述：TmstruckTimeTskResult服务实现
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@Service(value = "tmstruckTimeTaskResultService")
public class TmstruckTimeTaskResultServiceImpl implements ITmstruckTimeTaskResultService {

    @Autowired
    private TmstruckTimeTaskResultMapper tmstruckTimeTaskResultMapper;

    @Autowired
    private UtilsMapper utilsMapper;

    @Autowired
    private UtilsServiceImpl utilsService;

    @Autowired
    private OmsFeign omsFeign;

    @Autowired
    private BmsTruckFeign bmsTruckFeign;

    @Autowired
    private AmsFeign amsFeign;

    private static final String TwoHour="16吨吊车,12吨吊车,35吨吊车,25吨吊车,70吨吊车,80吨吊车,50吨吊车";

    private static final String FourHour="220吨吊车,130吨吊车,120吨吊车,150吨吊车,100吨吊车";
    private static final Set<String> FourHourSet;
    static {
        String arr[]={"220吨吊车","130吨吊车","120吨吊车","150吨吊车","100吨吊车"};
        FourHourSet=Arrays.stream(arr).collect(Collectors.toSet());
    }

    private static final String DxTemp="达兴能源二厂,化工厂";


    /**
     * 通用生成实例数据
     *
     * @param map
     * @return
     */
    public TmstruckTimeTaskResult generateTimeTaskResult(Map<String, Object> map) {
        TmstruckTimeTaskResult tmstruckTimeTaskResult = new TmstruckTimeTaskResult();
        //获取主键ID
        tmstruckTimeTaskResult.setId(tmstruckTimeTaskResultMapper.selectMaxId());
        String orderNumber = (String) map.get("orderNumber");
        BigDecimal inwardType = DataChange.dataToBigDecimal(map.get("inwardType"));
        //通过运输订单号查询总实绩ID等数据
        map.putAll(tmstruckTimeTaskResultMapper.getResultTotalIdByOrderNum(orderNumber));
        tmstruckTimeTaskResult.setResultTotalId(DataChange.dataToBigDecimal(map.get("resultTotalId")));
        //生成时间
        tmstruckTimeTaskResult.setResultTime(new Date());
        //生成订单结束
        tmstruckTimeTaskResult.setResultUomId(new BigDecimal(900));
        //设置时间类型
        tmstruckTimeTaskResult.setResultTimeType(inwardType);
        String personnelSsoId =(String) map.get("personnelSsoId");
        tmstruckTimeTaskResult.setInsertUsername(personnelSsoId);
        tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
        return tmstruckTimeTaskResult;
    }

    /**
     * 司机申请开始
     *
     * @param map
     * @return
     */
    @Override
    public int applyStartTime(Map<String, Object> map) {
        //设置时间类型 0
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }

    /**
     * 用车单位确认开始
     *
     * @param map
     * @return
     */
    @Override
    public int unitSureStartTime(Map<String, Object> map) {
        //设置时间类型 1
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }

    /**
     * 司机申请暂停
     *
     * @param map
     * @return
     */
    @Override
    public int applyStartTimeout(Map<String, Object> map) {
        //设置时间类型 4
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }

    /**
     * 用车单位确认
     *
     * @param map
     * @return
     */
    @Override
    public int unitSureStartTimeout(Map<String, Object> map) {
        //设置时间类型 5
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }

    /**
     * 司机申请暂停结束
     *
     * @param map
     * @return
     */
    @Override
    public int applyEndTimeout(Map<String, Object> map) {
        //设置时间类型 6
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }

    /**
     * 用车单位确认暂停结束
     *
     * @param map
     * @return
     */
    @Override
    public int unitSureEndTimeout(Map<String, Object> map) throws Exception {
        int i=0;
        //map中传输的参数为InwardType,orderNumber
        //根据运输订单号查找订单id
        //如果订单类型为5
        String personnelSsoId =(String) map.get("personnelSsoId");
        String orderNumber =(String) map.get("orderNumber");
        //根据运输订单号查找运输订单id
        BigDecimal orderId = utilsMapper.getOrderIdByOrderNumber(orderNumber);
        map.put("orderId",orderId);
        BigDecimal inwardType =DataChange.dataToBigDecimal(map.get("inwardType"));
        Integer lastStep=tmstruckTimeTaskResultMapper.getLastStep(orderId);
        //校验是否符合类型
        if(tmstruckTimeTaskResultMapper.checkOrderType(orderId)<=0){
            throw new Exception("该订单类型不允许计时");
        }
        //校验是否重复操作
        if(lastStep !=null && lastStep.compareTo(inwardType.intValue())==0){
            throw new Exception("请勿重复操作！");
        }
        if (inwardType.intValue()==5){
            generateTimeTaskResult(map);
        }else if (inwardType.intValue()==7){
            TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
            //生成计时实绩暂停
            //根据运输订单号查找总实绩id
            BigDecimal totalId = utilsMapper.getTotalIdByOrderNumber(orderNumber);
            //根据总实绩id查找开始时间
            Map<String, Object> lastTimeout = tmstruckTimeTaskResultMapper.getLastTimeout(totalId);
            Date startTime =(Date) lastTimeout.get("resultTime");
            //根据总实绩id查找结束时间
            Map<String, Object> lastTimeEnd = tmstruckTimeTaskResultMapper.getLastTimeEnd(totalId);
            Date EndTime = (Date) lastTimeEnd.get("resultTime");
            long dueTime=EndTime.getTime()-startTime.getTime();
            tmstruckTimeTaskResult.setTimeTaskResultId(tmstruckTimeTaskResult.getTimeTaskResultId());
            tmstruckTimeTaskResult.setResultValue(new BigDecimal((dueTime/(1000*60))));
            tmstruckTimeTaskResult.setUpdateTime(new Date());
            tmstruckTimeTaskResult.setUpdateUsername(personnelSsoId);
            i+=tmstruckTimeTaskResultMapper.updateByPrimaryKeySelective(tmstruckTimeTaskResult);

        }

        return i;
    }
   //判断计时订单结束后推单
    @Override
    public int pushOrderForPause(Map<String, Object> map) {
         int i=0;
         //关闭内转订单
         map.put("orderStatus", 2);
         i = utilsMapper.updateOrderStatusByOrderIdOrNum(map);
         BigDecimal orderId1 = DataChange.dataToBigDecimal(map.get("orderId"));
         map= tmstruckTimeTaskResultMapper.selectInwardDueTimeByOrderId(orderId1);
        //根据运输订单id查找需求日期是否超过一个月
        if(map != null) {
            Date dueDate = (Date) map.get("dueTime");
            //当前时间小于截至日期
            long DueTime = dueDate.getTime() + 86400000;
            //获取当前时间
            Date date = new Date();
            long nowTime = date.getTime();
            if (nowTime < DueTime) {
                //推送
                 omsFeign.addNewTransportOrder(orderId1);
            }
        }
        return i;
    }

    /**
     * 司机申请结束
     * @param map
     * @return
     */
    @Override
    public int applyEndTime(Map<String, Object> map) {
        //设置时间类型 2
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }

    /**
     * 用车单位确认结束
     * @param map
     * @return
     */
    @Override
    public int unitSureEndTime(Map<String, Object> map) {
        //设置时间类型 3
        TmstruckTimeTaskResult tmstruckTimeTaskResult = generateTimeTaskResult(map);
        //查询当前车辆排队开始时间 计算出总时长
        Map<String, Object> startTimeMap = tmstruckTimeTaskResultMapper.getStartTime(tmstruckTimeTaskResult.getResultTotalId());
        Date endTime = new Date();
        //计算当前时间与确认开始时间相差的毫秒数（时间戳）
        Date startTime = (Date) startTimeMap.get("resultTime");
        long allTime = endTime.getTime() - startTime.getTime();
        //查询所有确认暂停结束的时长时间戳
        List<Map<String, Object>> allTimeout = tmstruckTimeTaskResultMapper.getAllTimeout(tmstruckTimeTaskResult.getResultTotalId());
        long allTimeoutTime = 0;
        //计算所有暂停时间时长时间戳总和
        for (Map<String, Object> timeoutMap : allTimeout) {
            BigDecimal resultTime = DataChange.dataToBigDecimal(timeoutMap.get("resultValue"));
            allTimeoutTime += resultTime.longValue();
        }
        long realTime = allTime - allTimeoutTime;
        //计算总工作时长（分钟）
        realTime = realTime / (1000 * 60);
        tmstruckTimeTaskResult.setResultValue(new BigDecimal(realTime));
        return tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
    }


    /**
     * 查询计时作业
     * @param map
     * @return
     */
    @Override
    public List<Map<String, Object>> getAllTimeTaskResult(Map<String, Object> map) {
        List<Map<String, Object>> result=null;
        try{
            result = tmstruckTimeTaskResultMapper.getAllTimeTaskResult(map);
        }catch (Exception e){
            int i=3;
            while (i-->0 && tmstruckTimeTaskResultMapper.deleteErrorTimeTaskResult() > 0){
                //查询错误则删除错误计时数据，返回0或者执行3次后结束
            }
            result = tmstruckTimeTaskResultMapper.getAllTimeTaskResult(map);
        }
        return result;
    }

    /**
     * 添加计时作业实绩
     * @param map
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int addTimeTaskResult(Map<String, Object> map) throws Exception {
        //判断是否是计时开始还是计时结束
        int i=0;
        BigDecimal inwardType =DataChange.dataToBigDecimal(map.get("inwardTypes")) ;
        String orderNumber = (String) map.get("orderNumber");
        String personnelSsoId = (String) map.get("personnelSsoId");
        BigDecimal resultTotalId = utilsMapper.getTotalIdByOrderNumber(orderNumber);
        TmstruckTimeTaskResult tmstruckTimeTaskResult = new TmstruckTimeTaskResult();
        BigDecimal orderId = utilsMapper.getOrderIdByOrderNumber(orderNumber);
        map.put("orderId", orderId);
        Integer lastStep=tmstruckTimeTaskResultMapper.getLastStep(orderId);
        //校验是否符合类型
        if(tmstruckTimeTaskResultMapper.checkOrderType(orderId)<=0){
            throw new Exception("该订单类型不允许计时");
        }
        //校验是否重复操作
        if(lastStep !=null && lastStep.compareTo(inwardType.intValue())==0){
            throw new Exception("请勿重复操作");
        }
        //校验是否多次开始
        if(inwardType.intValue() == 1 && tmstruckTimeTaskResultMapper.CountStartTaskByOrderId(orderId) > 0){
            throw new Exception("请勿重复开始");
        }
        //校验是否多次结束
        if (inwardType.intValue() == 3 && tmstruckTimeTaskResultMapper.CountTimeTaskByOrderId(orderId) > 0) {
            throw new Exception("请勿重复结束");
        }
        tmstruckTimeTaskResult.setTimeTaskResultId(tmstruckTimeTaskResultMapper.selectMaxId());
        tmstruckTimeTaskResult.setResultTotalId(DataChange.dataToBigDecimal(resultTotalId));
        //获取计时开始的订单类型
        tmstruckTimeTaskResult.setResultTimeType(inwardType);
        tmstruckTimeTaskResult.setResultTime(new Date());
        tmstruckTimeTaskResult.setInsertTime(new Date());
        if (personnelSsoId!=null) {
            tmstruckTimeTaskResult.setInsertUsername(personnelSsoId);
        }
        //新增第一条计时实绩
        tmstruckTimeTaskResultMapper.insertSelective(tmstruckTimeTaskResult);
        if(inwardType.intValue() == 3){
            //获取最新暂停结束确认时间
            Map<String, Object> map2 = new HashMap<>();
            map2.put("type", 7);
            map2.put("orderId", orderId);
            BigDecimal resultPauseTime = utilsMapper.TimeTaskPause(map2);
            //通用处理
            Map<String, Object> timeMaps = utilsMapper.FristTimeTask(map);
            Date resultTime2 = (Date) timeMaps.get("resultTime");
            Map<String, Object> timeStatus = utilsMapper.getTimeStatus(map);
            Date resultTime1 = (Date) timeStatus.get("resultTime");
            long dateTime1 = resultTime2.getTime() - resultTime1.getTime();
            BigDecimal dateTime3 = new BigDecimal(dateTime1 / (1000 * 60));
            int Time1 = 0;//实际时长
            Map<String, Object> requirementInfo = tmstruckTimeTaskResultMapper.getRequirementInfo(orderId);
            String capacityTypeName =(String) requirementInfo.get("capacityTypeName");
            if(resultPauseTime != null) {
                //存在暂停时间
                Time1 = dateTime3.intValue() - resultPauseTime.intValue();
            } else {
                //不存在暂停时间
                Time1 = dateTime3.intValue();
            }
            //只要车辆类型不为空，就计算结算时长
            if (capacityTypeName != null) {
                //一般情况直接计算2小时规则
                int hour=Time1/60;
                int minutes=Time1%60;
                //判断是否小于2个小时
                if (hour<2){
                    //设置为两个小时
                    tmstruckTimeTaskResult.setResultAboutTime("2小时");
                    tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(120));
                }else {
                    //设置实际作业时长
                    tmstruckTimeTaskResult.setResultAboutTime(hour+"小时"+minutes+"分钟");
                    tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(Time1));
                }
                //特殊情况，根据不同计时规则重新计算
                //4小时规则：100吨以上吊车
                if (FourHourSet.contains(capacityTypeName)){
                    if (hour<4&&hour>=0){
                        //1、如实际使用时间不足4小时按照（使用时间+4小时）进行最终结算
                        tmstruckTimeTaskResult.setResultAboutTime(4+hour+"小时"+minutes+"分钟");
                        tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(240+Time1));
                    }else if (hour>=4&&hour<8){
                        //2、如实际使用时间超出4小时加上车辆往返时间4小时超过8小时的按8小时计算
                        tmstruckTimeTaskResult.setResultAboutTime("8小时");
                        tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(480));
                    }else if (hour>=8){
                        tmstruckTimeTaskResult.setResultAboutTime(hour+"小时"+minutes+"分钟");
                        tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(Time1));
                    }
                }
                //查询用车单位，使用特殊规则
                String shipperName=tmstruckTimeTaskResultMapper.getShipperName(map);
                if(shipperName!=null){
                    //达兴能源二厂及化工厂临时规则
                    if(shipperName.contains("达兴能源") || shipperName.contains("化工厂")){
                        if(capacityTypeName.contains("汽车")){
                            tmstruckTimeTaskResult.setResultAboutTime(1+hour+"小时"+minutes+"分钟");
                            tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(Time1+60));
                        }else if(capacityTypeName.contains("装载机")){
                            tmstruckTimeTaskResult.setResultAboutTime(4+hour+"小时"+minutes+"分钟");
                            tmstruckTimeTaskResult.setResultBalanceTime(new BigDecimal(Time1+240));
                        }
                    }
                }
            }
            tmstruckTimeTaskResult.setTimeTaskResultId(tmstruckTimeTaskResult.getTimeTaskResultId());
            tmstruckTimeTaskResult.setResultValue(new BigDecimal((Time1)));//实际时长
            tmstruckTimeTaskResult.setResultUomId(new BigDecimal(900));
            if (personnelSsoId != null) {
                tmstruckTimeTaskResult.setUpdateUsername(personnelSsoId);
            }
            i += tmstruckTimeTaskResultMapper.updateByPrimaryKeySelective(tmstruckTimeTaskResult);
            if(tmstruckTimeTaskResult.getResultBalanceTime()!=null && tmstruckTimeTaskResult.getResultBalanceTime().intValue()!=0){
                map.put("Time1",tmstruckTimeTaskResult.getResultBalanceTime());
            }else{
                map.put("Time1",Time1);
            }
            //计算完成
            Map<String, Object> orderMes = utilsMapper.getOrderTypeByOrderNumber(orderNumber);
            BigDecimal orderType =DataChange.dataToBigDecimal(orderMes.get("orderType"));
            if (orderType.intValue()==21) {
                //生成计时计费详单
                genernateInwardTime(map);
                pushOrderForPause(map);//包含关闭订单并推单
            }else if(orderType.intValue()==26){
                //关闭运输订单
                map.put("orderStatus", 2);
                i = utilsMapper.updateOrderStatusByOrderIdOrNum(map);
                //生成计次计费详单
                genernateInwardTime(map);
            }
         }
            return i;
        }




   //通过运输订单号判断计时是否开始
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int JudgeTimeTask(Map<String, Object> mapValue) throws Exception {
        String orderNumber =(String)mapValue.get("orderNumber");
        BigDecimal orderId = utilsMapper.getOrderIdByOrderNumber(orderNumber);
        //通过运输订单号查找当前是第几次
        BigDecimal inwardType = utilsMapper.getInwardType(orderId);
        if (inwardType!=null){
            throw new Exception("计时已经开始");
        }
        return inwardType.intValue();
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public int JudgeTimeTaskPause(Map<String, Object> mapValue) throws Exception {
        String orderNumber =(String)mapValue.get("orderNumber");
        int i=0;
        BigDecimal orderId = utilsMapper.getOrderIdByOrderNumber(orderNumber);
        //通过运输订单号查找当前是第几次
        BigDecimal inwardStartTime = utilsMapper.getInwardStartTime(orderId);
//        System.out.println(inwardStartTime);
        BigDecimal inwardEndTime = utilsMapper.getInwardEndTime(orderId);
//        System.out.println(inwardEndTime);
        int Time=inwardEndTime.intValue()-inwardStartTime.intValue();
//        System.out.println(Time);
       if (Time==0) {
           i=0;
       }else if (Time==-1){
           i=1;
       }else {
           i=3;
       }
        return i;
    }

    @Override
    public int genernateInwardTime(Map<String, Object> map) {
        int i=0;
        BigDecimal orderId1 = DataChange.dataToBigDecimal(map.get("orderId"));
        Map<String,Object>mapInfo = tmstruckTimeTaskResultMapper.getRequirementInfo(orderId1);
        Map<String,Object>mapPrice = null;
        try {
            mapPrice = amsFeign.getInwardPriceBy(mapInfo);//只查到计时，没有类型id
            if(mapPrice != null){
                mapPrice.put("orderId",orderId1);
                mapPrice.putAll(map);
                Map<String, Object> stringObjectMap = bmsTruckFeign.addInwardDetailsOrder(mapPrice);
                if (stringObjectMap==null){
                    return -1;
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        return i;
    }

    //修改计时时长
    @Transactional(rollbackFor = {Exception.class})
    @Override
    public int modifyTimeTaskResult(Map<String, Object> mapValue) throws Exception {
        String orderNumber =(String) mapValue.get("orderNumber");
        int i=0;
        Date resultTimeNew = null;
        SimpleDateFormat simpleDateFormat=new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String resultTime1 = (String) mapValue.get("resultTime");
        try {
             resultTimeNew = simpleDateFormat.parse( resultTime1);
        } catch (ParseException e) {
            e.printStackTrace();
        }
        long resultTime;
        BigDecimal resultValueNew=null;
        BigDecimal resultTimeEnd=null;
        TmstruckTimeTaskResult tmstruckTimeTaskResult=new TmstruckTimeTaskResult();
        //查找计时开始时间
        List<Map<String, Object>> startTimeTaskIdList = tmstruckTimeTaskResultMapper.getStartTimeTask(mapValue);
        Map<String,Object> map = tmstruckTimeTaskResultMapper.getResultValue(orderNumber);
        BigDecimal orderId =DataChange.dataToBigDecimal(map.get("orderId"));
        BigDecimal timeTaskResultId = DataChange.dataToBigDecimal(map.get("timeTaskResultId"));
        BigDecimal resultValue =DataChange.dataToBigDecimal(map.get("resultValue"));
        if (startTimeTaskIdList.size() != 1) {
            //根据运输订单查找是否有多条计时开始时间
            throw new Exception("计时开始超过一条或者没有计时开始时间");
        } else {
            Map<String, Object> stringObjectMap = startTimeTaskIdList.get(0);
           //获取计时总时长的实绩id
            Date resultTimeOld =(Date)stringObjectMap.get("resultTime");
            BigDecimal timeTaskResultIdStart = DataChange.dataToBigDecimal(stringObjectMap.get("timeTaskResultId"));
            if (DataChange.dataToBigDecimal(mapValue.get("resultType")).intValue()==1) {
                //修改计时开始时间
                //获取修改之前的计时开始时间，如果修改之前的计时开始时间大于修改之后的修改时间就date(resultTimeOld)-date(resultTimeNew)
                //resultValue+相差时长
                if (resultTimeOld.getTime()>resultTimeNew.getTime()) {
                    resultTime = resultTimeOld.getTime() - resultTimeNew.getTime();
                    resultTimeEnd = new BigDecimal(resultTime / (1000 * 60));
                    resultValueNew = resultTimeEnd.add(resultValue);
                }
                //获取修改之前的计时开始时间，如果修改之前的计时开始时间大于修改之后的修改时间就date(resultTimeNew)-date(resultTimeOld)
                //resultValue-相差时长
                if (resultTimeNew.getTime()>resultTimeOld.getTime()) {
                    resultTime = resultTimeNew.getTime() - resultTimeOld.getTime();
                    resultTimeEnd = new BigDecimal(resultTime / (1000 * 60));
                    resultValueNew = resultValue.subtract(resultTimeEnd);
                }
                tmstruckTimeTaskResult.setTimeTaskResultId(timeTaskResultIdStart);
                tmstruckTimeTaskResult.setResultTime(resultTimeNew);
                i+= tmstruckTimeTaskResultMapper.updateByPrimaryKeySelective(tmstruckTimeTaskResult);
            }else if (DataChange.dataToBigDecimal(mapValue.get("resultType")).intValue()==3){
                //修改计时结束时间
                //获取修改之后的计时结束时间，如果修改之前的计时结束时间大于修改之后的修改时间就date(resultTimeOld)-date(resultTimeNew)
                //resultValue-相差时长
                if (resultTimeOld.getTime()>resultTimeNew.getTime()) {
                    resultTime = resultTimeOld.getTime() - resultTimeNew.getTime();
                    resultTimeEnd = new BigDecimal(resultTime / (1000 * 60));
                    resultValueNew=resultValue.subtract(resultTimeEnd);
                }
                //获取修改之后的计时结束时间，如果修改之前的计时结束时间大于修改之后的修改时间就date(resultTimeNew)-date(resultTimeOld)
                //resultValue+相差时长
                if (resultTimeNew.getTime()>resultTimeOld.getTime()) {
                    resultTime = resultTimeNew.getTime() - resultTimeOld.getTime();
                    System.out.println(resultTime);
                    resultTimeEnd = new BigDecimal(resultTime / (1000 * 60));
                    //新的计时时长
                    resultValueNew=resultValue.add(resultTimeEnd);
                }
                tmstruckTimeTaskResult.setTimeTaskResultId(timeTaskResultIdStart);
                tmstruckTimeTaskResult.setResultTime(resultTimeNew);
                i+= tmstruckTimeTaskResultMapper.updateByPrimaryKeySelective(tmstruckTimeTaskResult);
            }else {
                throw new Exception("暂停时长不支持修改");
            }
            TmstruckTimeTaskResult tmstruckTimeTaskResult1=new TmstruckTimeTaskResult();
            tmstruckTimeTaskResult1.setTimeTaskResultId(timeTaskResultId);
            Map<String, Object> requirementInfo = tmstruckTimeTaskResultMapper.getRequirementInfo(orderId);
            String capacityTypeName =(String) requirementInfo.get("capacityTypeName");
            if (capacityTypeName.contains("吊车")) {
                //100吨以下
                if (resultValueNew==null){
                    throw new Exception("请确认是否修改了计时开始/结束时间");
                }
                BigDecimal hours=new BigDecimal(resultValueNew.intValue() / 60);
                BigDecimal minutes=new BigDecimal(resultValueNew.intValue()%60);
                int hour = Integer.parseInt(String.valueOf(hours));
                if (TwoHour.contains(capacityTypeName)) {
                    //判断是否小于2个小时
                    if (hour<2&&hour>0){
                        //设置为两个小时
                        tmstruckTimeTaskResult1.setResultAboutTime(2+"小时");
                    }else {
                        //设置实际作业时长-dateTime3
                        tmstruckTimeTaskResult1.setResultAboutTime(hour+"小时"+minutes+"分钟");
                    }
                    //如果为100吨以上吊车
                }else if (FourHourSet.contains(capacityTypeName)){
                    //1、如实际使用时间不足4小时按照（使用时间+4小时）进行最终结算
                    if (hour<0) {
                        tmstruckTimeTaskResult1.setResultAboutTime("4小时");
                    }
                    else if (hour<4&&hour>=0){
                        //计算小时和分钟
                        tmstruckTimeTaskResult1.setResultAboutTime(4+hours.intValue()+"小时"+minutes+"分钟");
                    }else if (hour>=4&&hour<8){
                        //2、如实际使用时间超出4小时加上车辆往返时间4小时超过8小时的按8小时计算
                        tmstruckTimeTaskResult1.setResultAboutTime(8+"小时");
                    }else if (hour>=8){
                        tmstruckTimeTaskResult1.setResultAboutTime(hours+"小时"+minutes+"分钟");
                    }
                }
            }

            tmstruckTimeTaskResult1.setInsertUpdateRemark("管理员修改时间");
            tmstruckTimeTaskResult1.setUpdateTime(new Date());
            tmstruckTimeTaskResult1.setResultValue(resultValueNew);
            tmstruckTimeTaskResult1.setUpdateUsername("admin");
             i+=tmstruckTimeTaskResultMapper.updateByPrimaryKeySelective(tmstruckTimeTaskResult1);
        }
        return i;
    }
}
